' 2ndChart.Bas

' This sample application demonstrates how
' to display a bar or column chart using the PG Toolbox

' $INCLUDE: 'CHRTB.BI'

CONST FALSE = 0, TRUE = NOT FALSE   ' define standard logical constants

DIM MyChart AS ChartEnvironment     ' My chart's environment variable
DIM ItemNo AS INTEGER               ' Item array index for input loop
DIM ScreenMode AS INTEGER
DIM UserTitle AS STRING, XAxisTitle AS STRING, YAxisTitle AS STRING

DECLARE SUB GetChartInfo (ChartType%, ChartVariation%)
DECLARE SUB WaitKey ()


' Request user to enter desired video mode

INPUT "Video (SCREEN) mode "; ScreenMode

ChartScreen ScreenMode              ' set video mode as user directed

IF ChartErr = cBadScreen THEN
  PRINT "The screen mode you entered is not compatible"
  PRINT "with the Presentation Graphics toolbox."
  END
END IF


' Ask the user how many series in their data

INPUT "How many data series do you want to chart ?", NSeries%
INPUT "How many items per series ?", MaxItems%


' Allocate the data storage as per user specification

DIM ItemValue(MaxItems%, NSeries%) AS SINGLE  ' Data series array
DIM ItemDesc(MaxItems%) AS STRING             ' Data legend label array
DIM SeriesLabels(NSeries%) AS STRING          ' Data series legend array


' Get the type of chart from the user

GetChartInfo ChartType%, ChartVariation%


' Set up the environment defaults for our chart

DefaultChart MyChart, ChartType%, ChartVariation%


' Set up some other aspects of our chart's environment

MyChart.MainTitle.TitleColor = 1    'use color 1
MyChart.MainTitle.Justify = cRight  'right-justify title
MyChart.SubTitle.TitleColor = 4     'use color 4
MyChart.SubTitle.Justify = cRight   'right-justify title


' Loop until user tires of creating charts

NextGraph:
  CLS 0
  LINE INPUT "Enter the title for your chart >", UserTitle
  IF LEN(UserTitle) = 0 THEN END
  MyChart.MainTitle.Title = UserTitle

  LINE INPUT "Enter a sub-title for your chart >", MyChart.SubTitle.Title

  LINE INPUT "Enter a title for the X-axis >", XAxisTitle
  MyChart.XAxis.AxisTitle.Title = XAxisTitle

  LINE INPUT "Enter a title for the Y-axis >", YAxisTitle
  MyChart.YAxis.AxisTitle.Title = YAxisTitle


  ' Get the series labels from the user

  FOR Series% = 1 TO NSeries%
     PRINT "Enter the legend label for series"; Series%;
     INPUT ">", SeriesLabels(Series%)
  NEXT Series%


  ' Get the item labels from the user

  FOR ItemNo = 1 TO MaxItems%
     PRINT "Enter the label for item"; ItemNo;
     INPUT "> ", ItemDesc(ItemNo)
  NEXT ItemNo


  ' Get the data item values from the user

  FOR Series% = 1 TO NSeries%
InLoop:
     PRINT "Series"; Series%; ":";
     INPUT "Enter item # or 0 when done with this series >"; ItemNo
     IF ItemNo = 0 THEN GOTO nextSeries

     ' check for out-of-range entry

     IF ItemNo > MaxItems% THEN
       PRINT "The Item number must be from 1 to "; MaxItems%; "."
       GOTO InLoop
     END IF

     ' does user want to edit an entry?

     IF ItemValue(ItemNo, Series%) <> 0 THEN

       ' show user current value

       PRINT "Series"; Series%; ", Item ";ItemNo; 
       PRINT "(";ItemDesc(ItemNo);")", ItemValue(ItemNo, Series%)
     END IF

     ' Get the value for this item

     PRINT "Amount for item"; ItemNo;
     INPUT "?", ItemValue(ItemNo, Series%)
     GOTO InLoop

nextSeries:
  NEXT Series%

' Display the chart, and wait for a key to be pressed

chartData:
  ChartMS MyChart, ItemDesc(), ItemValue(), MaxItems%, _
         1, NSeries%, SeriesLabels()
  WaitKey
  GOTO NextGraph
  END


SUB GetChartInfo (ChartType%, ChartVariation%) STATIC
'*********************************************************
' Return the chart type and variation (i.e. Stacked, etc.)
'*********************************************************

PRINT "Type 1 for a bar chart, 2 for a column chart, ";
INPUT "or 3 for a line chart >", ChartSelection%

IF ChartSelection% = 1 THEN
  ' Get the options for bar charts
  ChartType% = cBar
  PRINT "Type 1 for stacked bars, ";
  INPUT "or 2 for side-by-side bars >", ChartHow%
ELSE
  IF ChartSelection% = 2 THEN
    ' Get the options for column charts
    ChartType% = cColumn
    PRINT "Type 1 for stacked columns, ";
    INPUT "or 2 for side-by-side columns >", ChartHow%
  ELSE
    ' Get the options for line charts
    ChartType% = cLine
    PRINT "Type 1 for connecting lines, ";
    INPUT "or 2 for no connecting lines >", ChartHow%
  END IF
END IF

' Set up the chart variation

IF ChartType% = cBar OR ChartType% = cColumn THEN
  IF ChartHow% = 1 THEN
    ChartVariation% = cStacked
  ELSE
    ChartVariation% = cPlain
  END IF
ELSE
  IF ChartHow% = 1 THEN
    ChartVariation% = cLines
  ELSE
    ChartVariation% = cNoLines
  END IF
END IF
END SUB

SUB WaitKey STATIC
'*********************************************************
' Prompt the user to press a key
'*********************************************************
BEEP: DO WHILE INKEY$ = "": LOOP
END SUB

